package com.jh.boot.email;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.jh.boot.jpa.AbstractIdEntity;

/**
 * The Class EmailRecipient.
 */
@Entity
@Table(name = "EMAIL_RECIPIENT")
public class EmailRecipient extends AbstractIdEntity {

	/** The email. */
	@JsonIgnore
	@ManyToOne @org.hibernate.annotations.NotFound(action = org.hibernate.annotations.NotFoundAction.IGNORE)
	@JoinColumn(name = "EMAIL_ID")
	private Email email;
	
	/** The address. */
	@Column(name = "ADDRESS")
	private String address;
	
	/** The recipient type. */
	@Column(name = "RECIPIENT_TYPE")
	@Enumerated(EnumType.STRING)
	private RecipientType recipientType;

	/**
	 * Instantiates a new email recipient.
	 */
	public EmailRecipient() {
	}

	
	/**
	 * Instantiates a new email recipient.
	 *
	 * @param address the address
	 * @param recipientType the recipient type
	 */
	public EmailRecipient(String address, RecipientType recipientType) {
		this.address = address;
		this.recipientType = recipientType;
	}


	/**
	 * Gets the email.
	 *
	 * @return the email
	 */
	public Email getEmail() {
		return email;
	}

	/**
	 * Sets the email.
	 *
	 * @param email the new email
	 */
	public void setEmail(Email email) {
		this.email = email;
	}

	/**
	 * Gets the address.
	 *
	 * @return the address
	 */
	public String getAddress() {
		return address;
	}

	/**
	 * Sets the address.
	 *
	 * @param address the new address
	 */
	public void setAddress(String address) {
		this.address = address;
	}

	/**
	 * Gets the recipient type.
	 *
	 * @return the recipient type
	 */
	public RecipientType getRecipientType() {
		return recipientType;
	}

	/**
	 * Sets the recipient type.
	 *
	 * @param recipientType the new recipient type
	 */
	public void setRecipientType(RecipientType recipientType) {
		this.recipientType = recipientType;
	}


    @Override
    public int hashCode() {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + ((address == null) ? 0 : address.hashCode());
        result = prime * result + ((recipientType == null) ? 0 : recipientType.hashCode());
        return result;
    }


    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!super.equals(obj)) {
            return false;
        }
        if (!(obj instanceof EmailRecipient)) {
            return false;
        }
        EmailRecipient other = (EmailRecipient) obj;
        if (address == null) {
            if (other.address != null) {
                return false;
            }
        } else if (!address.equals(other.address)) {
            return false;
        }
        if (recipientType != other.recipientType) {
            return false;
        }
        return true;
    }
	
}
