package com.jh.boot.email;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import javax.persistence.Query;

import org.hibernate.query.NativeQuery;
import org.springframework.stereotype.Repository;

import com.jh.boot.jpa.AbstractHibernateRepository;

/**
 * The Class EmailRepository.
 */
@Repository
public class EmailRepository extends AbstractHibernateRepository {

	
	/**
	 * Fetch emails to send.
	 *
	 * @return the list
	 */
	@SuppressWarnings("unchecked")
	public List<Email> fetchEmailsToSend() {
		String sql = "select ID from EMAIL where LOCKED<>true and TO_BE_SENT=true for update limit 100";
		NativeQuery<Number> nq = nativeQuery(sql);
		
		//fetch ids
		List<Number> result = nq.getResultList();
		List<Long> ids = result.stream().map((n) -> n.longValue()).collect(Collectors.toList());
		
		if (!ids.isEmpty()) {
			lockEmails(ids, true);
			
			Query q = entityManager.createQuery("select distinct e from Email e left join fetch e.attachments left join fetch e.recipients where e.id in (:ids)");
			q.setParameter("ids", ids);
			
			return q.getResultList();
		}
		
		return Collections.emptyList();
	}
	
	
	/**
	 * Lock emails.
	 *
	 * @param ids the ids
	 * @param locked the locked
	 */
	public void lockEmails(Collection<Long> ids, boolean locked) {
		if (ids == null || ids.isEmpty()) {
			return;
		}
		String hql = "update Email e set e.locked=:locked where e.id in (:ids)";
		Query q = entityManager.createQuery(hql);
		q.setParameter("locked", locked);
		q.setParameter("ids", ids);
		q.executeUpdate();
	}
	
}
